@@ -135,7 +135,7 @@ void CfdDatacouplingMPI::allocate_external(int **&data, int len2,int len1,int in
 void CfdDatacouplingMPI::allocate_external(int    **&data, int len2,char *keyword,int initvalue)
 {
   int len1 = 0;
-  MultisphereParallel *ms_data = properties_->ms_data();
+  Multisphere *ms_data = properties_->ms_data();
 
   if(strcmp(keyword,"nparticles") == 0) len1 = atom->tag_max();
   else if(strcmp(keyword,"nbodies") == 0)
@@ -172,7 +172,7 @@ void CfdDatacouplingMPI::allocate_external(double **&data, int len2,int len1,dou
 void CfdDatacouplingMPI::allocate_external(double **&data, int len2,char *keyword,double initvalue)
 {
   int len1 = 0;
-  MultisphereParallel *ms_data = properties_->ms_data();
+  Multisphere *ms_data = properties_->ms_data();
 
   if(strcmp(keyword,"nparticles") == 0) len1 = atom->tag_max();
   else if(strcmp(keyword,"nbodies") == 0)
