@@ -78,8 +78,12 @@ ComputePairGranLocal::ComputePairGranLocal(LAMMPS *lmp, int narg, char **arg) :
   // store everything by default expect heat flux
   posflag = velflag = idflag = fflag = tflag = hflag = aflag = 1;
 
-  // do not store heat flux and delta by default
-  hfflag = dflag = 0;
+  // do not store fn, ft, heat flux, delta by default
+  fnflag = ftflag = hfflag = dflag = 0;
+
+  //no extra distance for building the list of pairs
+  verbose =false;
+  extraSurfDistance = 0.0;
 
   // if further args, store only the properties that are listed
   if(narg > 3)
@@ -92,13 +96,18 @@ ComputePairGranLocal::ComputePairGranLocal(LAMMPS *lmp, int narg, char **arg) :
     else if (strcmp(arg[iarg],"vel") == 0) velflag = 1;
     else if (strcmp(arg[iarg],"id") == 0) idflag = 1;
     else if (strcmp(arg[iarg],"force") == 0) fflag = 1;
+    else if (strcmp(arg[iarg],"force_normal") == 0) fnflag = 1;
+    else if (strcmp(arg[iarg],"force_tangential") == 0) ftflag = 1;
     else if (strcmp(arg[iarg],"torque") == 0) tflag = 1;
     else if (strcmp(arg[iarg],"history") == 0) hflag = 1;
     else if (strcmp(arg[iarg],"contactArea") == 0) aflag = 1;
     else if (strcmp(arg[iarg],"delta") == 0) dflag = 1;
     else if (strcmp(arg[iarg],"heatFlux") == 0) hfflag = 1;
     else if (strcmp(arg[iarg],"delta") == 0) hfflag = 1;
-    else error->compute_error(FLERR,this,"Invalid keyword");
+    else if (strcmp(arg[iarg],"verbose") == 0) verbose = true;
+    else if (strcmp(arg[iarg],"extraSurfDistance") == 0) {extraSurfDistance = atof(arg[iarg+1]); iarg++;}
+    else if(0 == strcmp(style,"wall/gran/local") || 0 == strcmp(style,"pair/gran/local"))
+        error->compute_error(FLERR,this,"illegal/unrecognized keyword");
   }
 
   // default: pair data
@@ -251,7 +260,7 @@ void ComputePairGranLocal::init_cpgl(bool requestflag)
   if(hflag && dnum == 0) error->all(FLERR,"Compute pair/gran/local or wall/gran/local can not calculate history values since pair or wall style does not compute them");
   // standard values: pos1,pos2,id1,id2,extra id for mesh wall,force,torque,contact area
 
-  nvalues = posflag*6 + velflag*6 + idflag*3 + fflag*3 + tflag*3 + hflag*dnum + aflag + dflag + hfflag;
+  nvalues = posflag*6 + velflag*6 + idflag*3 + fflag*3 + fnflag*3 + ftflag*3 + tflag*3 + hflag*dnum + aflag + dflag + hfflag;
   size_local_cols = nvalues;
 
 }
@@ -281,11 +290,13 @@ void ComputePairGranLocal::compute_local()
 
   // count local entries and compute pair info
 
-  if(wall == 0) ncount = count_pairs();        // # pairs is ensured to be the same for pair and heat
-  else          ncount = count_wallcontacts(); // # wall contacts ensured to be same for wall/gran and heat
+  int nCountWithOverlap(0);
+  if(wall == 0) ncount = count_pairs(nCountWithOverlap);            // # pairs is ensured to be the same for pair and heat
+  else          ncount = count_wallcontacts(nCountWithOverlap);     // # wall contacts ensured to be same for wall/gran and heat
 
+  //only consider rows with overlap (but allocate memory for all)
   if (ncount > nmax) reallocate(ncount);
-  size_local_rows = ncount;
+  size_local_rows = nCountWithOverlap;
 
   // get pair data
   if(wall == 0)
@@ -314,7 +325,7 @@ void ComputePairGranLocal::compute_local()
    count pairs on this proc
 ------------------------------------------------------------------------- */
 
-int ComputePairGranLocal::count_pairs()
+int ComputePairGranLocal::count_pairs(int & nCountWithOverlap)
 {
   int i,j,m,n,ii,jj,inum,jnum;
   double xtmp,ytmp,ztmp,delx,dely,delz,rsq;
@@ -337,7 +348,7 @@ int ComputePairGranLocal::count_pairs()
   // loop over neighbors of my atoms
   // skip if I or J are not in group
 
-  m = n = 0;
+  m = n = nCountWithOverlap = 0;
   for (ii = 0; ii < inum; ii++) {
     i = ilist[ii];
     if (!(mask[i] & groupbit)) continue;
@@ -360,10 +371,14 @@ int ComputePairGranLocal::count_pairs()
       dely = ytmp - x[j][1];
       delz = ztmp - x[j][2];
       rsq = delx*delx + dely*dely + delz*delz;
-      if (rsq >= (radius[i]+radius[j])*(radius[i]+radius[j])) continue;
+      if (rsq <  (radius[i]+radius[j])*(radius[i]+radius[j])) nCountWithOverlap++;
+      if (rsq >= (radius[i]+radius[j]+extraSurfDistance)*(radius[i]+radius[j]+extraSurfDistance)) continue;
       m++;
     }
   }
+  if(verbose)
+      printf("ComputePairGranLocal::count_pairs: detected %d pairs (extraSurfDistance: %g), and %d pairs with contact. \n",
+             m, extraSurfDistance, nCountWithOverlap);
   return m;
 }
 
@@ -371,10 +386,12 @@ int ComputePairGranLocal::count_pairs()
    count wall contacts on this proc
 ------------------------------------------------------------------------- */
 
-int ComputePairGranLocal::count_wallcontacts()
+int ComputePairGranLocal::count_wallcontacts(int & nCountWithOverlap)
 {
     // account for fix group
-    return fixwall->n_contacts_local(groupbit);
+    // no distinction between ncount and nCountWithOverlap for now
+    nCountWithOverlap = fixwall->n_contacts_local(groupbit);
+    return nCountWithOverlap;
 }
 
 /* ----------------------------------------------------------------------
@@ -391,9 +408,11 @@ void ComputePairGranLocal::add_pair(int i,int j,double fx,double fy,double fz,do
     if (!(atom->mask[j] & groupbit)) return;
 
     nlocal = atom->nlocal;
-
     if (newton_pair == 0 && j >= nlocal && atom->tag[i] <= atom->tag[j]) return;
 
+    if(!decide_add(hist))
+        return;
+
     xi = atom->x[i];
     xj = atom->x[j];
     vi = atom->v[i];
@@ -434,6 +453,35 @@ void ComputePairGranLocal::add_pair(int i,int j,double fx,double fy,double fz,do
         array[ipair][n++] = fy;
         array[ipair][n++] = fz;
     }
+    if(fnflag)
+    {
+        double fc[3],fn[3],normal[3];
+
+        vectorConstruct3D(fc,fx,fy,fz);
+        vectorSubtract3D(atom->x[j],atom->x[i],normal);
+        vectorNormalize3D(normal);
+        double fnmag = vectorDot3D(fc,normal);
+        vectorScalarMult3D(normal,fnmag,fn);
+
+        array[ipair][n++] = fn[0];
+        array[ipair][n++] = fn[1];
+        array[ipair][n++] = fn[2];
+    }
+    if(ftflag)
+    {
+        double fc[3],fn[3],ft[3],normal[3];
+
+        vectorConstruct3D(fc,fx,fy,fz);
+        vectorSubtract3D(atom->x[j],atom->x[i],normal);
+        vectorNormalize3D(normal);
+        double fnmag = vectorDot3D(fc,normal);
+        vectorScalarMult3D(normal,fnmag,fn);
+        vectorSubtract3D(fc,fn,ft);
+
+        array[ipair][n++] = ft[0];
+        array[ipair][n++] = ft[1];
+        array[ipair][n++] = ft[2];
+    }
     if(tflag)
     {
         array[ipair][n++] = tor1;
@@ -470,6 +518,13 @@ void ComputePairGranLocal::add_pair(int i,int j,double fx,double fy,double fz,do
 
 /* ---------------------------------------------------------------------- */
 
+void ComputePairGranLocal::pair_finalize()
+{
+    ncount_added_via_pair = ipair;
+}
+
+/* ---------------------------------------------------------------------- */
+
 void ComputePairGranLocal::add_heat(int i,int j,double hf)
 {
     if (newton_pair == 0 && j >= atom->nlocal && atom->tag[i] <= atom->tag[j]) return;
@@ -532,6 +587,25 @@ void ComputePairGranLocal::add_wall_1(int iFMG,int idTri,int iP,double *contact_
         
     }
 
+    if(fflag)
+    {
+        n += 3;
+    }
+
+    if(fnflag)
+    {
+        array[ipair][n++] = contact_point[0];
+        array[ipair][n++] = contact_point[1];
+        array[ipair][n++] = contact_point[2];
+    }
+
+    if(ftflag)
+    {
+        array[ipair][n++] = contact_point[0];
+        array[ipair][n++] = contact_point[1];
+        array[ipair][n++] = contact_point[2];
+    }
+
 }
 
 /* ---------------------------------------------------------------------- */
@@ -570,6 +644,43 @@ void ComputePairGranLocal::add_wall_2(int i,double fx,double fy,double fz,double
         array[ipair][n++] = fy;
         array[ipair][n++] = fz;
     }
+    if(fnflag)
+    {
+        double contact_point[3], fc[3],fn[3], normal[3];
+
+        contact_point[0] = array[ipair][n++];
+        contact_point[1] = array[ipair][n++];
+        contact_point[2] = array[ipair][n++];
+
+        vectorConstruct3D(fc,fx,fy,fz);
+        vectorSubtract3D(contact_point,atom->x[i],normal);
+        vectorNormalize3D(normal);
+        double fnmag = vectorDot3D(fc,normal);
+        vectorScalarMult3D(normal,fnmag,fn);
+
+        array[ipair][n-3] = fn[0];
+        array[ipair][n-2] = fn[1];
+        array[ipair][n-1] = fn[2];
+    }
+    if(ftflag)
+    {
+        double contact_point[3], fc[3],fn[3],ft[3], normal[3];
+
+        contact_point[0] = array[ipair][n++];
+        contact_point[1] = array[ipair][n++];
+        contact_point[2] = array[ipair][n++];
+
+        vectorConstruct3D(fc,fx,fy,fz);
+        vectorSubtract3D(contact_point,atom->x[i],normal);
+        vectorNormalize3D(normal);
+        double fnmag = vectorDot3D(fc,normal);
+        vectorScalarMult3D(normal,fnmag,fn);
+        vectorSubtract3D(fc,fn,ft);
+
+        array[ipair][n-3] = ft[0];
+        array[ipair][n-2] = ft[1];
+        array[ipair][n-1] = ft[2];
+    }
     if(tflag)
     {
         array[ipair][n++] = tor1;
