@@ -61,20 +61,28 @@ class ComputePairGranLocal : public Compute {
   void post_create();
   void pre_delete(bool uncomputeflag);
   void init();
-  void init_cpgl(bool requestflag);
+  virtual void init_cpgl(bool requestflag);
   void init_list(int, class NeighList *);
   void compute_local();
   double memory_usage();
   void reference_deleted();
-  void add_pair(int i,int j,double fx,double fy,double fz,double tor1,double tor2,double tor3,double *hist);
-  void add_heat(int i,int j,double hf);
-  void add_wall_1(int iFMG,int iTri,int iP,double *contact_point,double *v_wall);
-  void add_wall_2(int i,double fx,double fy,double fz,double tor1,double tor2,double tor3,double *hist,double rsq);
-  void add_heat_wall(int i,double hf);
+  virtual void add_pair(int i,int j,double fx,double fy,double fz,double tor1,double tor2,double tor3,double *hist);
+  virtual void add_heat(int i,int j,double hf);
+  virtual void add_wall_1(int iFMG,int iTri,int iP,double *contact_point,double *v_wall);
+  virtual void add_wall_2(int i,double fx,double fy,double fz,double tor1,double tor2,double tor3,double *hist,double rsq);
+  virtual void add_heat_wall(int i,double hf);
+
+  virtual void pair_finalize();
+  virtual bool decide_add(double *hist)
+  { return true; }
+
+ protected:
+
+  int nvalues;      // number of double values per entry
+  int ncount;       // count - from all who are touching up to all in neigh list, depending on extraSurfDistance
+  int ncount_added_via_pair; // count actually added via call from pair_gran
+                             // might be lower than ncount because is based on hasForceUpdate occurrences
 
- private:
-  int nvalues;
-  int ncount;
   int newton_pair;
 
   // if 0, pair data is extracted
@@ -92,7 +100,10 @@ class ComputePairGranLocal : public Compute {
 
   int ipair;
 
-  int posflag,velflag,idflag,fflag,tflag,hflag,aflag,dflag,hfflag;
+  int posflag,velflag,idflag,fflag,fnflag,ftflag,tflag,hflag,aflag,dflag,hfflag;
+
+  bool   verbose;
+  double extraSurfDistance;
 
   int dnum;
 
@@ -102,8 +113,8 @@ class ComputePairGranLocal : public Compute {
 
   class NeighList *list;
 
-  int count_pairs();
-  int count_wallcontacts();
+  virtual int count_pairs(int &nCountWithOverlap);
+  int count_wallcontacts(int &nCountWithOverlap);
   void reallocate(int);
 };
 
