@@ -33,7 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Richard Berger (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -91,6 +92,7 @@ Factory::Factory() {
   #include "style_normal_model.h"
   #undef NORMAL_MODEL
 
+  addTangentialModel("off", TANGENTIAL_OFF);
   #define TANGENTIAL_MODEL(identifier,str,constant) \
   addTangentialModel(#str, identifier);
   #include "style_tangential_model.h"
@@ -144,7 +146,7 @@ int64_t Factory::select_model(int & narg, char ** & args)
 
   // default configuration
   int model = -1;
-  int tangential = TANGENTIAL_NO_HISTORY;
+  int tangential = TANGENTIAL_OFF;
   int cohesion = COHESION_OFF;
   int rolling = ROLLING_OFF;
   int surface = SURFACE_DEFAULT;
