@@ -33,7 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Philippe Seil (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -57,7 +58,8 @@ using namespace LAMMPS_NS;
     refFrame_(REF_FRAME_UNDEFINED),
     restartType_(RESTART_TYPE_UNDEFINED),
     scalePower_(-1),
-    useDefault_(false)
+    useDefault_(false),
+    container_statistics_raw_data_(0)
   {
   }
 
@@ -67,9 +69,10 @@ using namespace LAMMPS_NS;
     refFrame_(REF_FRAME_UNDEFINED),
     restartType_(RESTART_TYPE_UNDEFINED),
     scalePower_(-1),
-    useDefault_(false)
+    useDefault_(false),
+    container_statistics_raw_data_(0)
   {
-      if(id_)
+      if(_id)
       {
         id_ = new char[strlen(_id)+1];
         strcpy(id_,_id);
@@ -82,7 +85,8 @@ using namespace LAMMPS_NS;
     refFrame_(REF_FRAME_UNDEFINED),
     restartType_(RESTART_TYPE_UNDEFINED),
     scalePower_(-1),
-    useDefault_(false)
+    useDefault_(false),
+    container_statistics_raw_data_(0)
   {
           setProperties(_id, _comm, _ref,_restart,_scalePower);
   }
@@ -93,7 +97,8 @@ using namespace LAMMPS_NS;
      refFrame_(orig.refFrame_),
      restartType_(orig.restartType_),
      scalePower_(orig.scalePower_),
-     useDefault_(orig.useDefault_)
+     useDefault_(orig.useDefault_),
+    container_statistics_raw_data_(orig.container_statistics_raw_data_)
   {
 
   }
@@ -144,3 +149,25 @@ using namespace LAMMPS_NS;
 
       return true;
   }
+
+  /* ----------------------------------------------------------------------
+   set container containing raw data for statistics calc
+  ------------------------------------------------------------------------- */
+
+  void ContainerBase::setContainerStatistics(class ContainerBase *_cb_stat)
+  {
+      container_statistics_raw_data_ = _cb_stat;
+  }
+
+  /* ----------------------------------------------------------------------
+   calc statistics - can be ave or variance
+  ------------------------------------------------------------------------- */
+
+  bool ContainerBase::calcStatistics(double weighting_factor)
+  {
+      if(strstr(id_,"average"))
+        return calcAveFromContainer(weighting_factor);
+      if(strstr(id_,"variance"))
+        return calcVarFromContainer(weighting_factor);
+      return false;
+  }
