@@ -33,7 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Philippe Seil (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -91,7 +92,7 @@
    decide if property is pushed or pulled at all
   ------------------------------------------------------------------------- */
 
-  inline bool ContainerBase::decidePackUnpackOperation(int operation,bool scale,bool translate, bool rotate)
+  inline bool ContainerBase::decidePackUnpackOperation(int operation,bool scale,bool translate, bool rotate) const
   {
       // return true for manual communication, such as for node_, node_orig_
       // etc in MultiNodeMeshParallel
@@ -141,7 +142,7 @@
    decide if operation performs data communication
   ------------------------------------------------------------------------- */
 
-  inline bool ContainerBase::decideCommOperation(int operation)
+  inline bool ContainerBase::decideCommOperation(int operation) const
   {
       
       if(operation == OPERATION_RESTART)
@@ -193,13 +194,13 @@
    note that rotation is only carried out for LEN_VEC==3
   ------------------------------------------------------------------------- */
 
-    bool ContainerBase::isScaleInvariant()
+    bool ContainerBase::isScaleInvariant() const
     {
        return ( refFrame_ == REF_FRAME_INVARIANT ||
                 refFrame_ == REF_FRAME_SCALE_TRANS_INVARIANT);
     }
 
-    bool ContainerBase::isTranslationInvariant()
+    bool ContainerBase::isTranslationInvariant() const
     {
         return ( refFrame_ == REF_FRAME_INVARIANT ||
                  refFrame_ == REF_FRAME_TRANS_ROT_INVARIANT ||
@@ -207,7 +208,7 @@
                  refFrame_ == REF_FRAME_TRANS_INVARIANT);
     }
 
-    bool ContainerBase::isRotationInvariant()
+    bool ContainerBase::isRotationInvariant() const
     {
         return ( refFrame_ == REF_FRAME_INVARIANT ||
                  refFrame_ == REF_FRAME_TRANS_ROT_INVARIANT ||
