@@ -33,7 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Philippe Seil (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -79,6 +80,15 @@ using namespace LAMMPS_NS;
    check if all containers have same length
   ------------------------------------------------------------------------- */
 
+  int CustomValueTracker::nElementProperties()
+  {
+    return elementProperties_.size();
+  }
+
+  /* ----------------------------------------------------------------------
+   check if all containers have same length
+  ------------------------------------------------------------------------- */
+
   void CustomValueTracker::check_element_property_consistency(int _len)
   {
     if (!elementProperties_.sameLength(_len))
@@ -126,6 +136,15 @@ using namespace LAMMPS_NS;
       
   }
 
+  /* ----------------------------------------------------------------------
+   calc statistics (averages, variances)
+  ------------------------------------------------------------------------- */
+
+  bool CustomValueTracker::calcStatistics(double weighting_factor)
+  {
+      return elementProperties_.calcStatistics(weighting_factor);
+  }
+
   /* ----------------------------------------------------------------------
    rotate all properties, applies to vector and multivector only
   ------------------------------------------------------------------------- */
