@@ -44,6 +44,7 @@
 #include "math.h"
 #include "mpi_liggghts.h"
 #include "fix_ave_euler.h"
+#include "fix_multisphere.h"
 #include "compute_stress_atom.h"
 #include "math_extra_liggghts.h"
 #include "atom.h"
@@ -149,13 +150,6 @@ FixAveEuler::FixAveEuler(LAMMPS *lmp, int narg, char **arg) :
        delete []errmsg;
      }
   }
-
-  // add nfirst to all computes that store invocation times
-  // since don't know a priori which are invoked via variables by this fix
-  // once in end_of_step() can set timestep for ones actually invoked
-
-  bigint nfirst = (update->ntimestep/nevery)*nevery + nevery;
-  modify->addstep_compute_all(nfirst);
 }
 
 /* ---------------------------------------------------------------------- */
@@ -191,6 +185,10 @@ void FixAveEuler::post_create()
         modify->add_compute(4,(char**)arg);
         compute_stress_ = static_cast<ComputeStressAtom*>(modify->compute[modify->find_compute(arg[0])]);
   }
+
+  // ensure that the compute is calculated in the first time step
+  bigint nfirst = (update->ntimestep/nevery)*nevery + nevery;
+  compute_stress_->addstep(nfirst);
 }
 
 /* ---------------------------------------------------------------------- */
@@ -211,6 +209,11 @@ void FixAveEuler::init()
   if(!atom->rmass_flag)
     error->fix_error(FLERR,this,"requires atom attribute mass");
 
+  // does not work with MS
+  FixMultisphere* fix_ms = static_cast<FixMultisphere*>(modify->find_fix_style_strict("multisphere",0));
+  if(fix_ms)
+      error->fix_error(FLERR,this,"does not work with multisphere");
+
   // check if box constant
   box_change_size_ = false;
   if(domain->box_change_size)
@@ -241,7 +244,7 @@ void FixAveEuler::init()
 void FixAveEuler::setup(int vflag)
 {
     setup_bins();
-    //end_of_step();
+    end_of_step();
 }
 
 /* ----------------------------------------------------------------------
@@ -521,7 +524,7 @@ inline int FixAveEuler::coord2bin(double *x)
 
 void FixAveEuler::calculate_eu()
 {
-    int ncount;
+    //int ncount;
     double **v = atom->v;
     double *radius = atom->radius;
     double *rmass = atom->rmass;
@@ -596,7 +599,7 @@ void FixAveEuler::calculate_eu()
     for(int icell = 0; icell < ncells_; icell++)
     {
         // calculate average vel and radius
-        if(ncount_[icell]) vectorScalarDiv3D(v_av_[icell],static_cast<double>(ncount_[icell])*mass_[icell]);
+        if(ncount_[icell]) vectorScalarDiv3D(v_av_[icell],mass_[icell]);
         if(ncount_[icell]) radius_[icell]/=static_cast<double>(ncount_[icell]);
 
         // calculate volume fraction
