@@ -64,8 +64,14 @@ FixCfdCouplingForceImplicit::FixCfdCouplingForceImplicit(LAMMPS *lmp, int narg,
     FixCfdCouplingForce(lmp,narg,arg),
     useCN_(false),
     CNalpha_(0.0),
+    useAM_(false),
+    CAddRhoFluid_(0.0),
+    onePlusCAddRhoFluid_(1.0),
     fix_Ksl_(0),
-    fix_uf_(0)
+    fix_uf_(0),
+    fix_KslRotation_(0),
+    fix_ex_(0),
+    fix_KslExtra_(0)
 {
     int iarg = 3;
 
@@ -80,10 +86,27 @@ FixCfdCouplingForceImplicit::FixCfdCouplingForceImplicit(LAMMPS *lmp, int narg,
             iarg++;
             useCN_ = true;
             CNalpha_ = atof(arg[iarg]);
+            if(CNalpha_<0 || CNalpha_>1)
+                error->fix_error(FLERR,this,"incorrect choice for 'CrankNicholson': setting CNalpha_<0 or CNalpha_>1 is not appropriate");
+
             fprintf(screen,"cfd_coupling_foce_implicit will use Crank-Nicholson scheme with %f\n", CNalpha_);
             iarg++;
             hasargs = true;
         }
+        else if (strcmp(arg[iarg],"CAddRhoFluid") == 0)
+        {
+            if(narg < iarg+2)
+                error->fix_error(FLERR,this,"not enough arguments for 'CAddRhoFluid'");
+            iarg++;
+            useAM_ = true;
+            CAddRhoFluid_        = atof(arg[iarg]);
+            onePlusCAddRhoFluid_ = 1.0 + CAddRhoFluid_;
+            fprintf(screen,"cfd_coupling_force_implicit will consider added mass with CAddRhoFluid = %f\n",
+                    CAddRhoFluid_);
+            iarg++;
+        }
+        else
+           iarg++;
     }
 
   nevery = 1;
@@ -145,6 +168,54 @@ void FixCfdCouplingForceImplicit::post_create()
         fixarg[10]="0.";
         fix_uf_ = modify->add_fix_property_atom(11,const_cast<char**>(fixarg),style);
     }
+    if(!fix_KslRotation_)
+    {
+      const char* fixarg[11];
+      fixarg[0]="KslRotation";
+      fixarg[1]="all";
+      fixarg[2]="property/atom";
+      fixarg[3]="KslRotation";
+      fixarg[4]="vector"; // 1 vector per particle to be registered
+      fixarg[5]="yes";    // restart
+      fixarg[6]="no";     // communicate ghost
+      fixarg[7]="no";     // communicate rev
+      fixarg[8]= "0.";
+      fixarg[9]= "0.";
+      fixarg[10]="0.";
+      fix_KslRotation_ = modify->add_fix_property_atom(11,const_cast<char**>(fixarg),style);
+     }
+    if(!fix_ex_)
+    {
+       const char* fixarg[11];
+       fixarg[0]="ex";
+       fixarg[1]="all";
+       fixarg[2]="property/atom";
+       fixarg[3]="ex";
+       fixarg[4]="vector"; // 1 vector per particle to be registered
+       fixarg[5]="yes";    // restart
+       fixarg[6]="no";     // communicate ghost
+       fixarg[7]="no";     // communicate rev
+       fixarg[8]= "0.";
+       fixarg[9]= "0.";
+       fixarg[10]="0.";
+       fix_ex_ = modify->add_fix_property_atom(11,const_cast<char**>(fixarg),style);
+    }
+    if(!fix_KslExtra_)
+    {
+      const char* fixarg[11];
+      fixarg[0]="KslExtra";
+      fixarg[1]="all";
+      fixarg[2]="property/atom";
+      fixarg[3]="KslExtra";
+      fixarg[4]="vector"; // 1 vector per particle to be registered
+      fixarg[5]="yes";    // restart
+      fixarg[6]="no";     // communicate ghost
+      fixarg[7]="no";     // communicate rev
+      fixarg[8]= "0.";
+      fixarg[9]= "0.";
+      fixarg[10]="0.";
+      fix_KslExtra_ = modify->add_fix_property_atom(11,const_cast<char**>(fixarg),style);
+    }
 }
 
 /* ---------------------------------------------------------------------- */
@@ -153,6 +224,9 @@ void FixCfdCouplingForceImplicit::pre_delete(bool unfixflag)
 {
     if(unfixflag && fix_Ksl_) modify->delete_fix("Ksl");
     if(unfixflag && fix_uf_) modify->delete_fix("uf");
+    if(unfixflag && fix_KslRotation_) modify->delete_fix("KslRotation");
+    if(unfixflag && fix_KslExtra_) modify->delete_fix("KslExtra");
+    if(unfixflag && fix_ex_) modify->delete_fix("ex");
 }
 
 /* ---------------------------------------------------------------------- */
@@ -164,6 +238,9 @@ void FixCfdCouplingForceImplicit::init()
     // values to come from OF
     fix_coupling_->add_pull_property("Ksl","scalar-atom");
     fix_coupling_->add_pull_property("uf","vector-atom");
+    fix_coupling_->add_pull_property("KslRotation","vector-atom");
+    fix_coupling_->add_pull_property("KslExtra","vector-atom");
+    fix_coupling_->add_pull_property("ex","vector-atom");
 
     deltaT_ = 0.5 * update->dt * force->ftm2v;
 }
@@ -236,8 +313,8 @@ void FixCfdCouplingForceImplicit::end_of_step()
   {
     if (mask[i] & groupbit)
     {
-      if (rmass)  KslMDeltaT = Ksl[i]/rmass[i]*deltaT_;
-      else        KslMDeltaT = Ksl[i]/mass[type[i]]*deltaT_;
+      if (rmass)  KslMDeltaT = Ksl[i]/(rmass[i]*onePlusCAddRhoFluid_)*deltaT_;
+      else        KslMDeltaT = Ksl[i]/(mass[type[i]]*onePlusCAddRhoFluid_)*deltaT_;
 
         for(int dirI=0;dirI<3;dirI++)
         {
@@ -260,7 +337,10 @@ void FixCfdCouplingForceImplicit::end_of_step()
            frc[dirI] = Ksl[i] * deltaU;  //force required for the next time step
 
            //update the particle velocity
-           v[i][dirI] += KslMDeltaT/2.0 * deltaU;  //update velocity for a half step!
+           //DCS IS NOW
+           v[i][dirI] = vN32[dirI];  //update velocity for a half step!
+           //RADL WAS
+           //v[i][dirI] += KslMDeltaT/2.0 * deltaU;;  //update velocity for a half step!
         }
 
          // add force
