@@ -103,7 +103,8 @@ FixContactHistory::FixContactHistory(LAMMPS *lmp, int narg, char **arg) :
   // initialize npartner to 0 so neighbor list creation is OK the 1st time
 
   int nlocal = atom->nlocal;
-  std::fill_n(npartner_, nlocal, 0);
+  
+  std::fill_n(npartner_, atom->nmax, 0);
 
   //=====================
   // parse args
@@ -218,6 +219,17 @@ void FixContactHistory::init()
           error->fix_error(FLERR,this,"Please use a granular pair style for fix contacthistory");
       pair_gran_ = static_cast<PairGran*>(force->pair_match("gran", 0));
 
+      if(dnum_ != static_cast<PairGran*>(pair_gran_)->dnum_pair())
+      {
+        pair_gran_ = static_cast<PairGran*>(force->pair_match("bubble", 0));
+
+        if(! pair_gran_ || dnum_ != static_cast<PairGran*>(pair_gran_)->dnum_pair())
+            pair_gran_ = static_cast<PairGran*>(force->pair_match("gran_bubble", 0));
+
+        if(!pair_gran_ || (dnum_ != static_cast<PairGran*>(pair_gran_)->dnum_pair()))
+            pair_gran_ = static_cast<PairGran*>(force->pair_match("gran", 0)); //at last, it must be a granular one! This is the case, e.g., in case extra history is used for liquid tracking
+      }
+
       int dim;
       computeflag_ = (int *) pair_gran_->extract("computeflag",dim);
   }
