@@ -207,6 +207,8 @@ void FixMeshSurfaceStress::zeroizeWear()
 
 void FixMeshSurfaceStress::init()
 {
+    FixMesh::init();
+
     if(stress_flag_)
     {
         f_ = mesh()->prop().getElementProperty<VectorContainer<double,3> >("f");
@@ -338,7 +340,7 @@ void FixMeshSurfaceStress::add_particle_contribution(int ip,double *frc,
         }
         E *= 2.*k_finnie_[atomTypeWall()-1][atom->type[ip]-1] * v_rel_mag * vectorMag3D(frc);
         
-        wear_step(iTri) += E / triMesh()->areaElem(iTri);
+        wear_step(iTri) += E*update->dt / triMesh()->areaElem(iTri);
     }
 }
 
