@@ -1,26 +1,42 @@
 /* ----------------------------------------------------------------------
-   LIGGGHTS® - LAMMPS Improved for General Granular and Granular Heat
-   Transfer Simulations
+    This is the
 
-   LIGGGHTS® is part of CFDEM®project
-   www.liggghts.com | www.cfdem.com
+    ██╗     ██╗ ██████╗  ██████╗  ██████╗ ██╗  ██╗████████╗███████╗
+    ██║     ██║██╔════╝ ██╔════╝ ██╔════╝ ██║  ██║╚══██╔══╝██╔════╝
+    ██║     ██║██║  ███╗██║  ███╗██║  ███╗███████║   ██║   ███████╗
+    ██║     ██║██║   ██║██║   ██║██║   ██║██╔══██║   ██║   ╚════██║
+    ███████╗██║╚██████╔╝╚██████╔╝╚██████╔╝██║  ██║   ██║   ███████║
+    ╚══════╝╚═╝ ╚═════╝  ╚═════╝  ╚═════╝ ╚═╝  ╚═╝   ╚═╝   ╚══════╝®
 
-   Christoph Kloss, christoph.kloss@cfdem.com
-   Copyright 2009-2012 JKU Linz
-   Copyright 2012-     DCS Computing GmbH, Linz
+    DEM simulation engine, released by
+    DCS Computing Gmbh, Linz, Austria
+    http://www.dcs-computing.com, office@dcs-computing.com
 
-   LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
-   the producer of the LIGGGHTS® software and the CFDEM®coupling software
-   See http://www.cfdem.com/terms-trademark-policy for details.
+    LIGGGHTS® is part of CFDEM®project:
+    http://www.liggghts.com | http://www.cfdem.com
 
-   LIGGGHTS® is based on LAMMPS
-   LAMMPS - Large-scale Atomic/Molecular Massively Parallel Simulator
-   http://lammps.sandia.gov, Sandia National Laboratories
-   Steve Plimpton, sjplimp@sandia.gov
+    Core developer and main author:
+    Christoph Kloss, christoph.kloss@dcs-computing.com
 
-   This software is distributed under the GNU General Public License.
+    LIGGGHTS® is open-source, distributed under the terms of the GNU Public
+    License, version 2 or later. It is distributed in the hope that it will
+    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. You should have
+    received a copy of the GNU General Public License along with LIGGGHTS®.
+    If not, see http://www.gnu.org/licenses . See also top-level README
+    and LICENSE files.
 
-   See the README file in the top-level directory.
+    LIGGGHTS® and CFDEM® are registered trade marks of DCS Computing GmbH,
+    the producer of the LIGGGHTS® software and the CFDEM®coupling software
+    See http://www.cfdem.com/terms-trademark-policy for details.
+
+-------------------------------------------------------------------------
+    Contributing author and copyright for this file:
+    (if not contributing author is listed, this file has been contributed
+    by the core developer)
+
+    Copyright 2012-     DCS Computing GmbH, Linz
+    Copyright 2009-2012 JKU Linz
 ------------------------------------------------------------------------- */
 
 /* -------------------------------------------------------------------------
@@ -86,6 +102,8 @@ FixTemplateMultiplespheres::FixTemplateMultiplespheres(LAMMPS *lmp, int narg, ch
       x_max[i] = -LARGE;
   }
 
+  overlap_slightly = no_overlap = false;
+
   // parse args
 
   if (narg < iarg+4) error->fix_error(FLERR,this,"not enough arguments");
@@ -198,6 +216,26 @@ void FixTemplateMultiplespheres::post_create()
 
     calc_bounding_sphere();
     calc_center_of_mass();
+
+    // check amount of overlap
+    // needed for some functionalities
+    check_overlap();
+
+    if(0 == strcmp(style,"particletemplate/multiplespheres"))
+        print_info();
+}
+
+/* ---------------------------------------------------------------------- */
+
+void FixTemplateMultiplespheres::print_info()
+{
+  if (logfile)
+  {
+    fprintf(logfile,"Finished calculating properties of template\n");
+    fprintf(logfile,"   mass = %e, radius of bounding sphere = %e, radius of equivalent sphere = %e\n",mass_expect,r_bound,r_equiv);
+    fprintf(logfile,"   center of mass = %e, %e, %e\n",0.,0.,0.);
+    fprintf(logfile,"   center of bounding sphere in global coords = %e, %e, %e\n",x_bound[0],x_bound[1],x_bound[2]);
+  }
 }
 
 /* ----------------------------------------------------------------------*/
@@ -206,7 +244,7 @@ int FixTemplateMultiplespheres::maxtype()
 {
     if(!atom_type_sphere)
         return atom_type;
-    return vectorMax3D(atom_type_sphere);
+    return vectorMaxN(atom_type_sphere,nspheres);
 }
 
 /* ----------------------------------------------------------------------*/
@@ -215,7 +253,7 @@ int FixTemplateMultiplespheres::mintype()
 {
     if(!atom_type_sphere)
         return atom_type;
-    return vectorMin3D(atom_type_sphere);
+    return vectorMinN(atom_type_sphere,nspheres);
 }
 
 /* ----------------------------------------------------------------------
@@ -241,7 +279,7 @@ void FixTemplateMultiplespheres::calc_bounding_sphere()
       double x_bound_temp[3],rbound_temp;
 
       while(isphere < 0 || visited[isphere] || isphere >= nspheres )
-          isphere = static_cast<int>(random->uniform()*nspheres);
+          isphere = static_cast<int>(random_mc->uniform()*nspheres);
 
       nvisited++;
       visited[isphere] = 1;
@@ -252,7 +290,7 @@ void FixTemplateMultiplespheres::calc_bounding_sphere()
       while(nvisited < nspheres)
       {
           while(isphere < 0 || visited[isphere] || isphere >= nspheres )
-               isphere = static_cast<int>(random->uniform()*nspheres);
+               isphere = static_cast<int>(random_mc->uniform()*nspheres);
 
           nvisited++;
           visited[isphere] = 1;
@@ -290,6 +328,50 @@ void FixTemplateMultiplespheres::calc_bounding_sphere()
 
 }
 
+/* ----------------------------------------------------------------------
+   check overlap of spheres against each other
+------------------------------------------------------------------------- */
+
+void FixTemplateMultiplespheres::check_overlap()
+{
+    
+    double overlap_slightly_min = 1.0000001;
+    double overlap_slightly_max = 1.01;
+
+    overlap_slightly = true;
+    no_overlap = true;
+
+    double dist;
+    bool *overlap_slightly_vec = new bool[nspheres];
+    vectorInitializeN(overlap_slightly_vec,nspheres,false);
+
+    for(int i = 0; i < nspheres; i++)
+    {
+        for(int j = i+1; j < nspheres; j++)
+        {
+            dist = pointDistance(x_sphere[i],x_sphere[j]);
+
+            if(dist < (r_sphere[i] + r_sphere[j]))
+                no_overlap = false;
+
+            if( (dist > overlap_slightly_min*(r_sphere[i] + r_sphere[j])) &&
+                (dist < overlap_slightly_max*(r_sphere[i] + r_sphere[j]))
+              )
+            {
+                overlap_slightly_vec[i] = true;
+                overlap_slightly_vec[j] = true;
+            }
+        }
+    }
+
+    // if any sphere has no slight overlap, result is false
+    for(int i = 0; i < nspheres; i++)
+        if(!overlap_slightly_vec[i])
+            overlap_slightly = false;
+
+    delete []overlap_slightly_vec;
+}
+
 /* ----------------------------------------------------------------------
    sqr distance from x_sphere[j] to xtest
 ------------------------------------------------------------------------- */
@@ -309,9 +391,9 @@ double FixTemplateMultiplespheres::dist_sqr(int j, double *xtest)
 
 void FixTemplateMultiplespheres::generate_xtry(double *x_try)
 {
-    x_try[0] = x_min[0]+(x_max[0]-x_min[0])*random->uniform();
-    x_try[1] = x_min[1]+(x_max[1]-x_min[1])*random->uniform();
-    x_try[2] = x_min[2]+(x_max[2]-x_min[2])*random->uniform();
+    x_try[0] = x_min[0]+(x_max[0]-x_min[0])*random_mc->uniform();
+    x_try[1] = x_min[1]+(x_max[1]-x_min[1])*random_mc->uniform();
+    x_try[2] = x_min[2]+(x_max[2]-x_min[2])*random_mc->uniform();
 }
 
 /* ----------------------------------------------------------------------
@@ -418,7 +500,7 @@ void FixTemplateMultiplespheres::randomize_single()
   pti->atom_type = atom_type;
   if(atom_type_sphere)
   {
-    vectorCopy3D(atom_type_sphere,pti->atom_type_vector);
+    vectorCopyN(atom_type_sphere,pti->atom_type_vector,nspheres);
     pti->atom_type_vector_flag = true;
   }
 
@@ -447,7 +529,7 @@ void FixTemplateMultiplespheres::init_ptilist(int n_random_max)
 
 /* ----------------------------------------------------------------------*/
 
-void FixTemplateMultiplespheres::randomize_ptilist(int n_random,int distribution_groupbit)
+void FixTemplateMultiplespheres::randomize_ptilist(int n_random,int distribution_groupbit,int distorder)
 {
     
     for(int i = 0; i < n_random; i++)
@@ -462,7 +544,7 @@ void FixTemplateMultiplespheres::randomize_ptilist(int n_random,int distribution
           pti->atom_type = atom_type;
           if(atom_type_sphere)
           {
-            vectorCopy3D(atom_type_sphere,pti->atom_type_vector);
+            vectorCopyN(atom_type_sphere,pti->atom_type_vector,nspheres);
             pti->atom_type_vector_flag = true;
           }
 
@@ -476,5 +558,7 @@ void FixTemplateMultiplespheres::randomize_ptilist(int n_random,int distribution
           vectorZeroize3D(pti->omega_ins);
 
           pti->groupbit = groupbit | distribution_groupbit; 
+
+          pti_list[i]->distorder = distorder;
     }
 }
