@@ -33,7 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Philippe Richard Berger (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -187,6 +188,10 @@ class FixWallGran : public Fix, public LIGGGHTS::IContactHistorySetup {
   int nlocal_;
   double **x_, **f_, *radius_, *rmass_, **wallforce_, r0_;
 
+#ifdef SUPERQUADRIC_ACTIVE_FLAG
+  double **quat_, **shape_, **roundness_;
+#endif
+
   void set_r0(double _r0)
   { r0_ = _r0; }
 
@@ -253,6 +258,9 @@ class FixWallGran : public Fix, public LIGGGHTS::IContactHistorySetup {
   // flag if mesh wall
   int meshwall_;
 
+  // flag to actiate potential energy calculation
+  bool track_energy_;
+
   // flag for stressanalysis
   // true if any of the meshes tracks stresses
   bool stress_flag_;
