@@ -33,7 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Richard Berger (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -55,6 +56,10 @@
 #include "contact_models.h"
 #include "granular_wall.h"
 
+#ifdef SUPERQUADRIC_ACTIVE_FLAG
+  #include "math_const.h"
+#endif
+
 namespace LIGGGHTS {
 using namespace ContactModels;
 namespace Walls {
@@ -67,7 +72,7 @@ class Granular : private Pointers, public IGranularWall {
 public:
   Granular(LAMMPS * lmp, FixWallGran * parent) :
     Pointers(lmp),
-    cmodel(lmp, parent),
+    cmodel(lmp, parent,true /*is_wall*/),
     parent(parent)
   {
   }
@@ -95,6 +100,7 @@ public:
     Settings settings(lmp);
     cmodel.registerSettings(settings);
     bool success = settings.parseArguments(nargs, args);
+    cmodel.postSettings();
 
 #ifdef LIGGGHTS_DEBUG
     if(comm->me == 0) {
@@ -139,9 +145,29 @@ public:
     const double r = sidata.r;
     const double rinv = 1.0/r;
 
+#ifdef SUPERQUADRIC_ACTIVE_FLAG
+    double enx, eny, enz;
+    if(atom->superquadric_flag) {
+    const double delta_inv = 1.0 / vectorMag3D(sidata.delta);
+      enx = sidata.delta[0] * delta_inv;
+      eny = sidata.delta[1] * delta_inv;
+      enz = sidata.delta[2] * delta_inv;
+      sidata.radi = cbrt(0.75 * atom->volume[ip] / M_PI);
+      Superquadric particle(sidata.pos_i, sidata.quat_i, sidata.shape_i, sidata.roundness_i);
+      sidata.koefi = particle.calc_curvature_coefficient(sidata.contact_point);
+      sidata.inertia_i = atom->inertia[ip];
+    } else { // sphere case
+      enx = sidata.delta[0] * rinv;
+      eny = sidata.delta[1] * rinv;
+      enz = sidata.delta[2] * rinv;
+      sidata.radi = radius;
+    }
+#else // sphere case
     const double enx = sidata.delta[0] * rinv;
     const double eny = sidata.delta[1] * rinv;
     const double enz = sidata.delta[2] * rinv;
+    sidata.radi = radius;
+#endif
 
     // copy collision data to struct (compiler can figure out a better way to
     // interleave these stores with the double calculations above.
@@ -154,7 +180,7 @@ public:
     sidata.en[1] = eny;
     sidata.en[2] = enz;
     sidata.i = ip;
-    sidata.radi = radius;
+    sidata.j = mesh?iTri : -1;
     sidata.contact_flags = NULL;
     sidata.itype = type[ip];
 
@@ -165,6 +191,8 @@ public:
 
     cmodel.surfacesIntersect(sidata, i_forces, j_forces);
 
+    cmodel.endSurfacesIntersect(sidata,mesh);
+
     if(sidata.computeflag) {
       force_update(f, torque, i_forces);
     }
