@@ -33,7 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Philippe Seil (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -159,7 +160,12 @@
         numElem_ += n;
         if(numElem_ >= maxElem_)
         {
+            T init_val = static_cast<T>(0);
             grow(arr_,numElem_+GROW,NUM_VEC,LEN_VEC);
+            for(int i = numElem_; i < numElem_+GROW; i++)
+                for(int j=0;j<NUM_VEC;j++)
+                    for(int k=0;k<LEN_VEC;k++)
+                          arr_[i][j][k] = init_val;
             maxElem_ = numElem_ + GROW;
         }
   }
@@ -171,9 +177,9 @@
   template<typename T, int NUM_VEC, int LEN_VEC>
   void GeneralContainer<T,NUM_VEC,LEN_VEC>::del(int n)
   {
+          
           numElem_--;
           if(numElem_ == n) return;
-          
           for(int i=0;i<NUM_VEC;i++)
                   for(int j=0;j<LEN_VEC;j++)
                           arr_[n][i][j] = arr_[numElem_][i][j];
@@ -311,6 +317,56 @@
       return true;
   }
 
+  /* ----------------------------------------------------------------------
+   average from other container
+  ------------------------------------------------------------------------- */
+
+  template<typename T, int NUM_VEC, int LEN_VEC>
+  bool GeneralContainer<T,NUM_VEC,LEN_VEC>::calcAveFromContainer(double weighting_factor)
+  {
+      GeneralContainer<T,NUM_VEC,LEN_VEC> *gcont = static_cast<GeneralContainer<T,NUM_VEC,LEN_VEC>* >(container_statistics_raw_data_);
+
+      if(size() != gcont->size() || nVec() != gcont->nVec() || lenVec() != gcont->lenVec())
+        return false;
+
+      int len = size();
+      for(int n = 0; n < len; n++)
+          for(int i=0;i<NUM_VEC;i++)
+                  for(int j=0;j<LEN_VEC;j++)
+                  {
+                          arr_[n][i][j] = (1.-weighting_factor)*arr_[n][i][j]+weighting_factor*gcont->arr_[n][i][j];
+                          
+                  }
+
+      return true;
+  }
+
+  /* ----------------------------------------------------------------------
+   variance from other container
+  ------------------------------------------------------------------------- */
+
+  template<typename T, int NUM_VEC, int LEN_VEC>
+  bool GeneralContainer<T,NUM_VEC,LEN_VEC>::calcVarFromContainer(double weighting_factor)
+  {
+      GeneralContainer<T,NUM_VEC,LEN_VEC> *gcont = static_cast<GeneralContainer<T,NUM_VEC,LEN_VEC>* >(container_statistics_raw_data_);
+
+      if(size() != gcont->size() || nVec() != gcont->nVec() || lenVec() != gcont->lenVec())
+        return false;
+
+      int len = size();
+      for(int n = 0; n < len; n++)
+          for(int i=0;i<NUM_VEC;i++)
+                  for(int j=0;j<LEN_VEC;j++)
+                  {
+                          // TODO HERE this is ave
+                          arr_[n][i][j] = (1.-weighting_factor)*arr_[n][i][j]+weighting_factor*gcont->arr_[n][i][j];
+                          //arr_[n][i][j] = (1.-weighting_factor)*arr_[n][i][j]+weighting_factor*gcont->arr_[n][i][j];
+                          
+                  }
+
+      return true;
+  }
+
   /* ---------------------------------------------------------------------- */
 
   template<typename T, int NUM_VEC, int LEN_VEC>
@@ -470,7 +526,7 @@
   ------------------------------------------------------------------------- */
 
   template<typename T, int NUM_VEC, int LEN_VEC>
-  int GeneralContainer<T,NUM_VEC,LEN_VEC>::bufSize(int operation,bool scale,bool translate,bool rotate)
+  int GeneralContainer<T,NUM_VEC,LEN_VEC>::bufSize(int operation,bool scale,bool translate,bool rotate) const
   {
       if(!this->decidePackUnpackOperation(operation,scale,translate,rotate))
             return 0;
