@@ -33,7 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Richard Berger (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -53,6 +54,7 @@ using namespace std;
 
 namespace MODEL_PARAMS
 {
+  static const char * COHESION_DISTANCE_SETTINGS = "cohesionDistanceSettings";
   static const char * COHESION_ENERGY_DENSITY = "cohesionEnergyDensity";
   static const char * CHARACTERISTIC_VELOCITY = "characteristicVelocity";
   static const char * YOUNGS_MODULUS = "youngsModulus";
@@ -75,6 +77,7 @@ namespace MODEL_PARAMS
   static const char * COEFFICIENT_PLASTICITY_DEPTH = "coefficientPlasticityDepth";
   static const char * ROUGHNESS_ABSOLUTE = "roughnessAbsolute";
   static const char * ROUGHNESS_RELATIVE = "roughnessRelative";
+  static const char * ROLLING_STIFFNESS = "rollingStiffness";
 
   /* -----------------------------------------------------------------------
    * Utility functions
@@ -88,6 +91,65 @@ namespace MODEL_PARAMS
     return scalar;
   }
 
+  ScalarProperty* createScalarProperty(PropertyRegistry & registry, const char* name, const char * caller, bool sanity_checks, const double lo, const double hi)
+  {
+    LAMMPS * lmp = registry.getLAMMPS();
+
+    ScalarProperty * scalar = new ScalarProperty();
+    FixPropertyGlobal * property = registry.getGlobalProperty(name,"property/global","scalar",0,0,caller);
+
+    const double value = property->compute_scalar();
+    if (sanity_checks)
+    {
+      if (value < lo || value > hi)
+      {
+        char buf[200];
+        sprintf(buf,"%s requires values between %g and %g \n",name,lo,hi);
+        lmp->error->all(FLERR,buf);
+      }
+    }
+
+    scalar->data = value;
+    return scalar;
+  }
+
+  VectorProperty* createPerTypeProperty(PropertyRegistry & registry, const char* name, const char * caller)
+  {
+    const int max_type = registry.max_type();
+
+    VectorProperty * vector = new VectorProperty(max_type+1);
+    FixPropertyGlobal * property = registry.getGlobalProperty(name,"property/global","vector",max_type,0,caller);
+    for(int i = 1; i < max_type+1; i++)
+        vector->data[i] = property->compute_vector(i-1);
+
+    return vector;
+  }
+
+  VectorProperty* createPerTypeProperty(PropertyRegistry & registry, const char* name, const char * caller, bool sanity_checks, const double lo, const double hi)
+  {
+    LAMMPS * lmp = registry.getLAMMPS();
+    const int max_type = registry.max_type();
+
+    VectorProperty * vector = new VectorProperty(max_type+1);
+    FixPropertyGlobal * property = registry.getGlobalProperty(name,"property/global","vector",max_type,0,caller);
+    for(int i = 1; i < max_type+1; i++)
+    {
+      const double value = property->compute_vector(i-1);
+      if (sanity_checks)
+      {
+        if (value < lo || value > hi)
+        {
+          char buf[200];
+          sprintf(buf,"%s requires values between %g and %g \n",name,lo,hi);
+          lmp->error->all(FLERR,buf);
+        }
+      }
+      vector->data[i] = value;
+    }
+
+    return vector;
+  }
+
   MatrixProperty* createPerTypePairProperty(PropertyRegistry & registry, const char * name, const char * caller)
   {
     const int max_type = registry.max_type();
@@ -106,6 +168,35 @@ namespace MODEL_PARAMS
     return matrix;
   }
 
+  MatrixProperty* createPerTypePairProperty(PropertyRegistry & registry, const char * name, const char * caller, bool sanity_checks, const double lo, const double hi)
+  {
+    LAMMPS * lmp = registry.getLAMMPS();
+    const int max_type = registry.max_type();
+
+    MatrixProperty * matrix = new MatrixProperty(max_type+1, max_type+1);
+    FixPropertyGlobal *   property = registry.getGlobalProperty(name,"property/global","peratomtypepair",max_type,max_type,caller);
+
+    for(int i = 1; i < max_type+1; i++)
+    {
+      for(int j = 1; j < max_type+1; j++)
+      {
+        const double value = property->compute_array(i-1,j-1);
+        if (sanity_checks)
+        {
+          if (value < lo || value > hi)
+          {
+            char buf[200];
+            sprintf(buf,"%s requires values between %g and %g \n",name,lo,hi);
+            lmp->error->all(FLERR,buf);
+          }
+        }
+        matrix->data[i][j] = value;
+      }
+    }
+
+    return matrix;
+  }
+
   /* -----------------------------------------------------------------------
    * Property Creators
    * ----------------------------------------------------------------------- */
@@ -134,6 +225,32 @@ namespace MODEL_PARAMS
 
   /* ---------------------------------------------------------------------- */
 
+  VectorProperty * createCohesionDistanceSettings(PropertyRegistry & registry, const char * caller, bool sanity_checks)
+  {
+    LAMMPS * lmp = registry.getLAMMPS();
+    int        numSettings = 4;        //use 4 settings, starting index = 0
+    VectorProperty *   vec = new VectorProperty(numSettings); 
+    FixPropertyGlobal * ca = registry.getGlobalProperty(COHESION_DISTANCE_SETTINGS,"property/global","vector",numSettings,0,caller);
+
+    for(int i=0; i <numSettings; i++)
+    {
+      const double aSetting = ca->compute_vector(i);
+
+      // error checks on v
+      if(sanity_checks)
+      {
+        if(aSetting < 0.0)
+          lmp->error->all(FLERR,"distance settings for cohesion model must be all positive");
+      }
+
+      vec->data[i] = aSetting;
+    }
+
+    return vec;
+  }
+
+  /* ---------------------------------------------------------------------- */
+
   VectorProperty * createYoungsModulus(PropertyRegistry & registry, const char * caller, bool sanity_checks)
   {
     LAMMPS * lmp = registry.getLAMMPS();
@@ -435,6 +552,23 @@ namespace MODEL_PARAMS
 
   /* ---------------------------------------------------------------------- */
 
+  ScalarProperty* createRollingStiffness(PropertyRegistry & registry, const char * caller, bool sanity_checks)
+  {
+    LAMMPS * lmp = registry.getLAMMPS();
+    ScalarProperty* rollingStiffness = createScalarProperty(registry, ROLLING_STIFFNESS, caller);
+    double rollStiffness = rollingStiffness->data;
+
+    if(sanity_checks)
+    {
+      if(strcmp(lmp->update->unit_style,"si") == 0  && rollStiffness < 1.0 )
+        lmp->error->all(FLERR,"rollingStiffness >= 1 required for SI units");
+    }
+
+    return rollingStiffness;
+  }
+
+  /* ---------------------------------------------------------------------- */
+
   ScalarProperty* createLiquidVolume(PropertyRegistry & registry, const char * caller, bool)
   {
     return createScalarProperty(registry, LIQUID_VOLUME, caller);
