@@ -54,11 +54,14 @@ class InputMeshTri : protected Input
     InputMeshTri(class LAMMPS *, int, char **);
     ~InputMeshTri();
 
-    void meshtrifile(const char *,class TriMesh *,bool verbose);
+    void meshtrifile(const char *,class TriMesh *,bool verbose,const int size_exclusion_list, int *exclusion_list);
 
   private:
 
     bool verbose_;
+    int i_exclusion_list_;
+    int size_exclusion_list_;
+    int *exclusion_list_;
 
     void meshtrifile_vtk(class TriMesh *);
     void meshtrifile_stl(class TriMesh *);
