@@ -35,7 +35,8 @@
     (if not contributing author is listed, this file has been contributed
     by the core developer)
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Philippe Seil (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -60,6 +61,7 @@
     random_(new RanPark(lmp,179424799)), // big prime #
     mesh_id_(0),
     precision_(EPSILON_PRECISION),
+    element_exclusion_list_(0),
     autoRemoveDuplicates_(false),
     nMove_(0),
     nScale_(0),
@@ -100,6 +102,12 @@
       precision_ = _precision;
   }
 
+  template<int NUM_NODES>
+  void MultiNodeMesh<NUM_NODES>::setElementExclusionList(FILE *_file)
+  {
+      element_exclusion_list_ = _file;
+  }
+
   template<int NUM_NODES>
   void MultiNodeMesh<NUM_NODES>::autoRemoveDuplicates()
   {
