@@ -32,7 +32,8 @@
 
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Richard Berger (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -63,7 +64,7 @@ namespace ContactModels
   public:
     static const int MASK = CM_REGISTER_SETTINGS | CM_CONNECT_TO_PROPERTIES | CM_SURFACES_INTERSECT;
 
-    NormalModel(LAMMPS * lmp, IContactHistorySetup*) : Pointers(lmp),
+    NormalModel(LAMMPS * lmp, IContactHistorySetup*,class ContactModelBase *c) : Pointers(lmp),
       Yeff(NULL),
       Geff(NULL),
       coeffRestMax(NULL),
@@ -75,7 +76,10 @@ namespace ContactModels
       tangential_damping(false),
       limitForce(false),
       ktToKn(false),
-      displayedSettings(false)
+      displayedSettings(false),
+      heating(false),
+      heating_track(false),
+      cmb(c)
     {
       
     }
@@ -86,6 +90,8 @@ namespace ContactModels
       settings.registerOnOff("tangential_damping", tangential_damping, true);
       settings.registerOnOff("limitForce", limitForce);
       settings.registerOnOff("ktToKnUser", ktToKn);
+      settings.registerOnOff("heating_normal_hooke",heating,false);
+      settings.registerOnOff("heating_tracking",heating_track,false);
     }
 
     inline void connectToProperties(PropertyRegistry & registry) {
@@ -131,6 +137,10 @@ namespace ContactModels
       double ri = sidata.radi;
       double rj = sidata.radj;
       double reff=sidata.is_wall ? ri : (ri*rj/(ri+rj));
+#ifdef SUPERQUADRIC_ACTIVE_FLAG
+      if(sidata.is_non_spherical)
+        reff = MathExtraLiggghtsSuperquadric::get_effective_radius(sidata);
+#endif
       double meff=sidata.meff;
       double coeffRestLogChosen;
 
@@ -170,8 +180,8 @@ namespace ContactModels
       kt /= force->nktv2p;
 
       const double Fn_damping = -gamman*sidata.vn;
-      const double Fn_contact = kn*(sidata.radsum-sidata.r);
-      double Fn                         = Fn_damping + Fn_contact;
+      const double Fn_contact = kn*sidata.deltan;
+      double Fn = Fn_damping + Fn_contact;
 
       //limit force to avoid the artefact of negative repulsion force
       if(limitForce && (Fn<0.0) )
@@ -185,12 +195,37 @@ namespace ContactModels
       sidata.gamman = gamman;
       sidata.gammat = gammat;
 
+      #ifdef SUPERQUADRIC_ACTIVE_FLAG
+          double torque_i[3];
+          double Fn_i[3] = { Fn * sidata.en[0], Fn * sidata.en[1], Fn * sidata.en[2]};
+          if(sidata.is_non_spherical) {
+            double xci[3];
+            vectorSubtract3D(sidata.contact_point, sidata.pos_i, xci);
+            vectorCross3D(xci, Fn_i, torque_i);
+          }
+      #endif
+
+      if(heating)
+      {
+        sidata.P_diss += fabs(Fn_damping*sidata.vn); //fprintf(screen,"  contrib %f\n",fabs(Fn_damping*sidata.vn));}
+        if(heating_track && sidata.is_wall) cmb->tally_pw(fabs(Fn_damping*sidata.vn),sidata.i,jtype,0);
+        if(heating_track && !sidata.is_wall) cmb->tally_pp(fabs(Fn_damping*sidata.vn),sidata.i,sidata.j,0);
+      }
+
       // apply normal force
       if(sidata.is_wall) {
         const double Fn_ = Fn * sidata.area_ratio;
         i_forces.delta_F[0] = Fn_ * sidata.en[0];
         i_forces.delta_F[1] = Fn_ * sidata.en[1];
         i_forces.delta_F[2] = Fn_ * sidata.en[2];
+        #ifdef SUPERQUADRIC_ACTIVE_FLAG
+                if(sidata.is_non_spherical) {
+                  //for non-spherical particles normal force can produce torque!
+                  i_forces.delta_torque[0] += torque_i[0];
+                  i_forces.delta_torque[1] += torque_i[1];
+                  i_forces.delta_torque[2] += torque_i[2];
+                }
+        #endif
       } else {
         const double fx = sidata.Fn * sidata.en[0];
         const double fy = sidata.Fn * sidata.en[1];
@@ -203,6 +238,23 @@ namespace ContactModels
         j_forces.delta_F[0] = -fx;
         j_forces.delta_F[1] = -fy;
         j_forces.delta_F[2] = -fz;
+        #ifdef SUPERQUADRIC_ACTIVE_FLAG
+                if(sidata.is_non_spherical) {
+                  //for non-spherical particles normal force can produce torque!
+                  double xcj[3], torque_j[3];
+                  double Fn_j[3] = { -Fn_i[0], -Fn_i[1], -Fn_i[2]};
+                  vectorSubtract3D(sidata.contact_point, sidata.pos_j, xcj);
+                  vectorCross3D(xcj, Fn_j, torque_j);
+
+                  i_forces.delta_torque[0] += torque_i[0];
+                  i_forces.delta_torque[1] += torque_i[1];
+                  i_forces.delta_torque[2] += torque_i[2];
+
+                  j_forces.delta_torque[0] += torque_j[0];
+                  j_forces.delta_torque[1] += torque_j[1];
+                  j_forces.delta_torque[2] += torque_j[2];
+                }
+        #endif
       }
     }
 
@@ -224,6 +276,9 @@ namespace ContactModels
     bool limitForce;
     bool ktToKn;
     bool displayedSettings;
+    bool heating;
+    bool heating_track;
+    class ContactModelBase *cmb;
   };
 }
 }
