@@ -34,7 +34,8 @@
     Contributing author and copyright for this file:
 
     Richard Berger (JKU Linz)
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
     Copyright 2009-2012 JKU Linz
@@ -61,12 +62,14 @@ PairGranProxy::~PairGranProxy()
 void PairGranProxy::settings(int nargs, char ** args)
 {
   delete impl;
+
   int64_t variant = Factory::instance().selectVariant("gran", nargs, args);
   impl = Factory::instance().create("gran", variant, lmp, this);
 
   if(impl) {
     impl->settings(nargs, args);
   } else {
+    
     error->one(FLERR, "unknown contact model");
   }
 }
@@ -113,6 +116,11 @@ double PairGranProxy::stressStrainExponent()
   return impl->stressStrainExponent();
 }
 
+int PairGranProxy::bond_history_offset()
+{
+  return impl->bond_history_offset();
+}
+
 int64_t PairGranProxy::hashcode() {
   return impl->hashcode();
 }
