@@ -32,7 +32,8 @@
 
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Andreas Aigner (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
