@@ -34,7 +34,8 @@
     Contributing author and copyright for this file:
 
     Stefan Amberger (JKU Linz)
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
     Copyright 2009-2012 JKU Linz
@@ -528,7 +529,7 @@ void RegWedge::printProperty(const char *name, double val){
 
 void RegWedge::printContacts(double *x, int n){
   for (int i = 0; i<n; i++){
-    printf("step "BIGINT_FORMAT" Contact %i\n",update->ntimestep,i);
+    printf("step " BIGINT_FORMAT " Contact %i\n",update->ntimestep,i);
     printf("\tx\t: %f\t%f\t%f\n",x[0],x[1],x[2]);
     printf("\tr\t: %f\n\tdx\t: %f\n\tdy\t: %f\n\tdz\t: %f\n",contact[i].r,contact[i].delx,contact[i].dely,contact[i].delz);
   }
