@@ -8,6 +8,7 @@
 #include "compute_contact_atom.h"
 #include "compute_coord_atom.h"
 #include "compute_displace_atom.h"
+#include "compute_erotate_multisphere.h"
 #include "compute_erotate_sphere_atom.h"
 #include "compute_erotate_sphere.h"
 #include "compute_group_group.h"
@@ -16,6 +17,7 @@
 #include "compute_inertia_molecule.h"
 #include "compute_ke_atom.h"
 #include "compute_ke.h"
+#include "compute_ke_multisphere.h"
 #include "compute_msd.h"
 #include "compute_msd_molecule.h"
 #include "compute_nparticles_tracer_region.h"
@@ -29,6 +31,7 @@
 #include "compute_rdf.h"
 #include "compute_reduce.h"
 #include "compute_reduce_region.h"
+#include "compute_rigid.h"
 #include "compute_slice.h"
 #include "compute_stress_atom.h"
 #include "compute_surface.h"
