@@ -1,9 +1,6 @@
-#include "dump_atom.h"
 #include "dump_atom_vtk.h"
-#include "dump_cfg.h"
 #include "dump_custom.h"
 #include "dump_custom_vtk.h"
-#include "dump_dcd.h"
 #include "dump_decomposition_vtk.h"
 #include "dump_euler_vtk.h"
 #include "dump_image.h"
