@@ -33,7 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Philippe Seil (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -50,13 +51,13 @@
 #include "vector_liggghts.h"
 #include "random_park.h"
 #include "memory_ns.h"
+#include "region_neighbor_list.h"
 #include "mpi_liggghts.h"
 #include "comm.h"
 #include <cmath>
 #include "math_extra_liggghts.h"
 
 #define EPSILON_CURVATURE 0.00001
-#define MIN_ANGLE_MESH 0.5 // in degress
 
 using namespace LAMMPS_MEMORY_NS;
 
@@ -70,6 +71,7 @@ class SurfaceMesh : public TrackingMesh<NUM_NODES>
         //virtual double distToElem(int nElem, double *p) = 0;
 
         void setCurvature(double _curvature);
+        void setCurvatureTolerant(bool _tol);
         
         bool addElement(double **nodeToAdd,int lineNumb);
 
@@ -141,7 +143,7 @@ class SurfaceMesh : public TrackingMesh<NUM_NODES>
         void qualityCheck();
 
         void buildNeighbours();
-        void parallelCorrection();
+        virtual void parallelCorrection();
 
         // returns true if surfaces share an edge
         // called with local index
@@ -193,8 +195,9 @@ class SurfaceMesh : public TrackingMesh<NUM_NODES>
         inline bool*    hasNonCoplanarSharedNode(int i) {return (hasNonCoplanarSharedNode_)(i);}
         inline int& obtuseAngleIndex(int i) {return obtuseAngleIndex_(i); }
 
-        inline int nBelowAngle()            {return nBelowAngle_;}
-        inline double angleLimit()          {return acos(minAngle_)*180./M_PI;}
+        inline int nBelowAngleSoftLimit()   {return nBelowAngle_softLimit_;}
+        inline double angleSoftLimit()      {return acos(minAngle_softLimit_)*180./M_PI;}
+        inline double angleHardLimit()      {return acos(minAngle_hardLimit_)*180./M_PI;}
         inline int nTooManyNeighs()         {return nTooManyNeighs_;}
         inline int nOverlapping()           {return nOverlapping_;}
 
@@ -206,10 +209,12 @@ class SurfaceMesh : public TrackingMesh<NUM_NODES>
 
         // mesh properties
         double curvature_;
-        double minAngle_; 
+        bool curvature_tolerant_;
+        double minAngle_softLimit_;         
+        double minAngle_hardLimit_;         
         ScalarContainer<double>& areaMesh_; 
 
-        int nBelowAngle_;
+        int nBelowAngle_softLimit_;
         int nTooManyNeighs_;
         int nOverlapping_;
 
@@ -221,7 +226,7 @@ class SurfaceMesh : public TrackingMesh<NUM_NODES>
         ScalarContainer<double>& area_;
         ScalarContainer<double>& areaAcc_;                    // accumulated area of owned and ghost particles
         VectorContainer<double,NUM_NODES>& edgeLen_;          // len of edgeVec
-        MultiVectorContainer<double,NUM_NODES,3>& edgeVec_;   // unit vec from node0 to node1 etc
+        MultiVectorContainer<double,NUM_NODES,3>& edgeVec_;   // unit vec from node0 to node1, node1 to node2 etc
         MultiVectorContainer<double,NUM_NODES,3>& edgeNorm_;
         VectorContainer<double,3>& surfaceNorm_;
         ScalarContainer<int>& obtuseAngleIndex_;
@@ -233,6 +238,10 @@ class SurfaceMesh : public TrackingMesh<NUM_NODES>
         VectorContainer<bool,NUM_NODES>& hasNonCoplanarSharedNode_;
         VectorContainer<bool,NUM_NODES>& edgeActive_;
         VectorContainer<bool,NUM_NODES>& cornerActive_;
+
+        // for overlap check on element insertion
+        
+        RegionNeighborList &neighList_;
 };
 
 // *************************************
