@@ -33,7 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Richard Berger (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -41,7 +42,7 @@
 ------------------------------------------------------------------------- */
 
 #ifdef TANGENTIAL_MODEL
-TANGENTIAL_MODEL(TANGENTIAL_HISTORY,history,1)
+TANGENTIAL_MODEL(TANGENTIAL_HISTORY,history,2)
 #else
 #ifndef TANGENTIAL_MODEL_HISTORY_H_
 #define TANGENTIAL_MODEL_HISTORY_H_
@@ -63,8 +64,11 @@ namespace ContactModels
   public:
     static const int MASK = CM_CONNECT_TO_PROPERTIES | CM_SURFACES_INTERSECT | CM_SURFACES_CLOSE;
 
-    TangentialModel(LAMMPS * lmp, IContactHistorySetup * hsetup) : Pointers(lmp),
-      coeffFrict(NULL)
+    TangentialModel(LAMMPS * lmp, IContactHistorySetup * hsetup,class ContactModelBase *c) : Pointers(lmp),
+      coeffFrict(NULL),
+      heating(false),
+      heating_track(false),
+      cmb(c)
     {
       history_offset = hsetup->add_history_value("shearx", "1");
       hsetup->add_history_value("sheary", "1");
@@ -72,7 +76,12 @@ namespace ContactModels
 
     }
 
-    inline void registerSettings(Settings&){}
+    inline void registerSettings(Settings& settings)
+    {
+        settings.registerOnOff("heating_tangential_history",heating,false);
+        settings.registerOnOff("heating_tracking",heating_track,false);
+        //TODO error->one(FLERR,"TODO here also check if right surface model used");
+    }
 
     inline void connectToProperties(PropertyRegistry & registry)
     {
@@ -122,9 +131,17 @@ namespace ContactModels
       if (Ft_shear > Ft_friction) {
         if (shrmag != 0.0) {
           const double ratio = Ft_friction / Ft_shear;
+          
+          if(heating)
+          {
+            sidata.P_diss += (vectorMag3DSquared(shear)*kt - ratio*ratio*vectorMag3DSquared(shear)*kt) / (update->dt); 
+            if(heating_track && sidata.is_wall) cmb->tally_pw((vectorMag3DSquared(shear)*kt - ratio*ratio*vectorMag3DSquared(shear)*kt) / (update->dt),sidata.i,sidata.jtype,2);
+            if(heating_track && !sidata.is_wall) cmb->tally_pp((vectorMag3DSquared(shear)*kt - ratio*ratio*vectorMag3DSquared(shear)*kt) / (update->dt),sidata.i,sidata.j,2);
+          }
           Ft1 *= ratio;
           Ft2 *= ratio;
           Ft3 *= ratio;
+          
           shear[0] = -Ft1/kt;
           shear[1] = -Ft2/kt;
           shear[2] = -Ft3/kt;
@@ -137,6 +154,12 @@ namespace ContactModels
         Ft1 -= (gammat*sidata.vtr1);
         Ft2 -= (gammat*sidata.vtr2);
         Ft3 -= (gammat*sidata.vtr3);
+        if(heating)
+        {
+            sidata.P_diss += gammat*(sidata.vtr1*sidata.vtr1+sidata.vtr2*sidata.vtr2+sidata.vtr3*sidata.vtr3); 
+            if(heating_track && sidata.is_wall) cmb->tally_pw(gammat*(sidata.vtr1*sidata.vtr1+sidata.vtr2*sidata.vtr2+sidata.vtr3*sidata.vtr3),sidata.i,sidata.jtype,1);
+            if(heating_track && !sidata.is_wall) cmb->tally_pp(gammat*(sidata.vtr1*sidata.vtr1+sidata.vtr2*sidata.vtr2+sidata.vtr3*sidata.vtr3),sidata.i,sidata.j,1);
+        }
       }
 
       // forces & torques
@@ -144,29 +167,69 @@ namespace ContactModels
       const double tor2 = enz * Ft1 - enx * Ft3;
       const double tor3 = enx * Ft2 - eny * Ft1;
 
+      #ifdef SUPERQUADRIC_ACTIVE_FLAG
+          double torque_i[3];
+          if(sidata.is_non_spherical) {
+            double xci[3];
+            double Ft_i[3] = { Ft1,  Ft2,  Ft3 };
+            vectorSubtract3D(sidata.contact_point, sidata.pos_i, xci);
+            vectorCross3D(xci, Ft_i, torque_i);
+          } else {
+            torque_i[0] = -sidata.cri * tor1;
+            torque_i[1] = -sidata.cri * tor2;
+            torque_i[2] = -sidata.cri * tor3;
+          }
+      #endif
       // return resulting forces
       if(sidata.is_wall) {
         const double area_ratio = sidata.area_ratio;
         i_forces.delta_F[0] += Ft1 * area_ratio;
         i_forces.delta_F[1] += Ft2 * area_ratio;
         i_forces.delta_F[2] += Ft3 * area_ratio;
-        i_forces.delta_torque[0] = -sidata.cri * tor1 * area_ratio;
-        i_forces.delta_torque[1] = -sidata.cri * tor2 * area_ratio;
-        i_forces.delta_torque[2] = -sidata.cri * tor3 * area_ratio;
+        #ifdef SUPERQUADRIC_ACTIVE_FLAG
+                i_forces.delta_torque[0] += torque_i[0] * area_ratio;
+                i_forces.delta_torque[1] += torque_i[1] * area_ratio;
+                i_forces.delta_torque[2] += torque_i[2] * area_ratio;
+        #else
+                i_forces.delta_torque[0] = -sidata.cri * tor1 * area_ratio;
+                i_forces.delta_torque[1] = -sidata.cri * tor2 * area_ratio;
+                i_forces.delta_torque[2] = -sidata.cri * tor3 * area_ratio;
+        #endif
       } else {
         i_forces.delta_F[0] += Ft1;
         i_forces.delta_F[1] += Ft2;
         i_forces.delta_F[2] += Ft3;
-        i_forces.delta_torque[0] = -sidata.cri * tor1;
-        i_forces.delta_torque[1] = -sidata.cri * tor2;
-        i_forces.delta_torque[2] = -sidata.cri * tor3;
-
         j_forces.delta_F[0] += -Ft1;
         j_forces.delta_F[1] += -Ft2;
         j_forces.delta_F[2] += -Ft3;
-        j_forces.delta_torque[0] = -sidata.crj * tor1;
-        j_forces.delta_torque[1] = -sidata.crj * tor2;
-        j_forces.delta_torque[2] = -sidata.crj * tor3;
+        #ifdef SUPERQUADRIC_ACTIVE_FLAG
+                double torque_j[3];
+                if(sidata.is_non_spherical) {
+                  double xcj[3];
+                  vectorSubtract3D(sidata.contact_point, sidata.pos_j, xcj);
+                  double Ft_j[3] = { -Ft1,  -Ft2,  -Ft3 };
+                  vectorCross3D(xcj, Ft_j, torque_j);
+                } else {
+                  torque_j[0] = -sidata.crj * tor1;
+                  torque_j[1] = -sidata.crj * tor2;
+                  torque_j[2] = -sidata.crj * tor3;
+                }
+                i_forces.delta_torque[0] += torque_i[0];
+                i_forces.delta_torque[1] += torque_i[1];
+                i_forces.delta_torque[2] += torque_i[2];
+
+                j_forces.delta_torque[0] += torque_j[0];
+                j_forces.delta_torque[1] += torque_j[1];
+                j_forces.delta_torque[2] += torque_j[2];
+        #else
+                i_forces.delta_torque[0] = -sidata.cri * tor1;
+                i_forces.delta_torque[1] = -sidata.cri * tor2;
+                i_forces.delta_torque[2] = -sidata.cri * tor3;
+
+                j_forces.delta_torque[0] = -sidata.crj * tor1;
+                j_forces.delta_torque[1] = -sidata.crj * tor2;
+                j_forces.delta_torque[2] = -sidata.crj * tor3;
+        #endif
       }
     }
 
@@ -183,6 +246,11 @@ namespace ContactModels
 
     inline void beginPass(SurfacesIntersectData&, ForceData&, ForceData&){}
     inline void endPass(SurfacesIntersectData&, ForceData&, ForceData&){}
+
+   protected:
+    bool heating;
+    bool heating_track;
+    class ContactModelBase *cmb;
   };
 }
 }
