@@ -33,7 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Richard Berger (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -41,7 +42,7 @@
 ------------------------------------------------------------------------- */
 
 #ifdef TANGENTIAL_MODEL
-TANGENTIAL_MODEL(TANGENTIAL_NO_HISTORY,no_history,0)
+TANGENTIAL_MODEL(TANGENTIAL_NO_HISTORY,no_history,1)
 #else
 #ifndef TANGENTIAL_MODEL_NO_HISTORY_H_
 #define TANGENTIAL_MODEL_NO_HISTORY_H_
@@ -63,7 +64,7 @@ namespace ContactModels
   public:
     static const int MASK = CM_CONNECT_TO_PROPERTIES | CM_SURFACES_INTERSECT;
 
-    TangentialModel(LAMMPS * lmp, IContactHistorySetup*) : Pointers(lmp), coeffFrict(NULL)
+    TangentialModel(LAMMPS * lmp, IContactHistorySetup*,class ContactModelBase *) : Pointers(lmp), coeffFrict(NULL)
     {
       
     }
@@ -102,29 +103,69 @@ namespace ContactModels
       const double tor2 = (enz*Ft1 - enx*Ft3);
       const double tor3 = (enx*Ft2 - eny*Ft1);
 
+      #ifdef SUPERQUADRIC_ACTIVE_FLAG
+          double torque_i[3];
+          if(sidata.is_non_spherical) {
+            double xci[3];
+            double Ft_i[3] = { Ft1,  Ft2,  Ft3 };
+            vectorSubtract3D(sidata.contact_point, sidata.pos_i, xci);
+            vectorCross3D(xci, Ft_i, torque_i);
+          } else {
+            torque_i[0] = -sidata.cri * tor1;
+            torque_i[1] = -sidata.cri * tor2;
+            torque_i[2] = -sidata.cri * tor3;
+          }
+      #endif
       // return resulting forces
       if(sidata.is_wall) {
         const double area_ratio = sidata.area_ratio;
         i_forces.delta_F[0] += Ft1 * area_ratio;
         i_forces.delta_F[1] += Ft2 * area_ratio;
         i_forces.delta_F[2] += Ft3 * area_ratio;
-        i_forces.delta_torque[0] = -sidata.cri * tor1 * area_ratio;
-        i_forces.delta_torque[1] = -sidata.cri * tor2 * area_ratio;
-        i_forces.delta_torque[2] = -sidata.cri * tor3 * area_ratio;
+        #ifdef SUPERQUADRIC_ACTIVE_FLAG
+                i_forces.delta_torque[0] += torque_i[0] * area_ratio;
+                i_forces.delta_torque[1] += torque_i[1] * area_ratio;
+                i_forces.delta_torque[2] += torque_i[2] * area_ratio;
+        #else
+                i_forces.delta_torque[0] = -sidata.cri * tor1 * area_ratio;
+                i_forces.delta_torque[1] = -sidata.cri * tor2 * area_ratio;
+                i_forces.delta_torque[2] = -sidata.cri * tor3 * area_ratio;
+        #endif
       } else {
         i_forces.delta_F[0] += Ft1;
         i_forces.delta_F[1] += Ft2;
         i_forces.delta_F[2] += Ft3;
-        i_forces.delta_torque[0] = -sidata.cri * tor1;
-        i_forces.delta_torque[1] = -sidata.cri * tor2;
-        i_forces.delta_torque[2] = -sidata.cri * tor3;
-
         j_forces.delta_F[0] -= Ft1;
         j_forces.delta_F[1] -= Ft2;
         j_forces.delta_F[2] -= Ft3;
-        j_forces.delta_torque[0] = -sidata.crj * tor1;
-        j_forces.delta_torque[1] = -sidata.crj * tor2;
-        j_forces.delta_torque[2] = -sidata.crj * tor3;
+        #ifdef SUPERQUADRIC_ACTIVE_FLAG
+                double torque_j[3];
+                if(sidata.is_non_spherical) {
+                  double xcj[3];
+                  vectorSubtract3D(sidata.contact_point, sidata.pos_j, xcj);
+                  double Ft_j[3] = { -Ft1,  -Ft2,  -Ft3 };
+                  vectorCross3D(xcj, Ft_j, torque_j);
+                } else {
+                  torque_j[0] = -sidata.crj * tor1;
+                  torque_j[1] = -sidata.crj * tor2;
+                  torque_j[2] = -sidata.crj * tor3;
+                }
+                i_forces.delta_torque[0] += torque_i[0];
+                i_forces.delta_torque[1] += torque_i[1];
+                i_forces.delta_torque[2] += torque_i[2];
+
+                j_forces.delta_torque[0] += torque_j[0];
+                j_forces.delta_torque[1] += torque_j[1];
+                j_forces.delta_torque[2] += torque_j[2];
+        #else
+                i_forces.delta_torque[0] = -sidata.cri * tor1;
+                i_forces.delta_torque[1] = -sidata.cri * tor2;
+                i_forces.delta_torque[2] = -sidata.cri * tor3;
+
+                j_forces.delta_torque[0] = -sidata.crj * tor1;
+                j_forces.delta_torque[1] = -sidata.crj * tor2;
+                j_forces.delta_torque[2] = -sidata.crj * tor3;
+        #endif
       }
     }
 
