@@ -33,7 +33,8 @@
 -------------------------------------------------------------------------
     Contributing author and copyright for this file:
 
-    Christoph Kloss (DCS Computing GmbH, Linz, JKU Linz)
+    Christoph Kloss (DCS Computing GmbH, Linz)
+    Christoph Kloss (JKU Linz)
     Philippe Seil (JKU Linz)
 
     Copyright 2012-     DCS Computing GmbH, Linz
@@ -47,9 +48,17 @@
 #include "atom.h"
 #include "math_extra_liggghts.h"
 #include "tri_line.h"
+#include "superquadric_flag.h"
+
 #ifdef TRI_LINE_ACTIVE_FLAG
 #include "math_extra_dist_lineTriangle.h"
 #endif
+
+#ifdef SUPERQUADRIC_ACTIVE_FLAG
+#include "math_extra_liggghts_superquadric.h"
+using namespace MathExtraLiggghtsSuperquadric;
+#endif
+
 #include <fstream>
 
 namespace LAMMPS_NS
@@ -68,6 +77,20 @@ namespace LAMMPS_NS
         double resolveTriSphereContactBary(int iPart, int nTri, double rSphere, double *cSphere,
                                            double *contactPoint,double *bary);
 
+        #ifdef SUPERQUADRIC_ACTIVE_FLAG
+
+        double resolveTriSuperquadricContact(int nTri, double *normal, double *contactPoint, Superquadric particle);
+        double resolveTriSuperquadricContact(int nTri, double *normal, double *contactPoint, Superquadric particle, double *bary);
+
+        bool sphereTriangleIntersection(int nTri, double rSphere, double *cSphere);
+        int superquadricTriangleIntersection(int nTri, double *point_of_lowest_potential, Superquadric particle);
+        double resolveEdgeContactBary(int iTri, int iEdge, double *p, double *delta, double *bary, bool triActive);
+        double resolveCornerContactBary(int iTri, int iNode, bool obtuse,
+                                                              double *p, double *delta, double *bary, bool treatActive);
+        double pointToTriangleDistance(int iTri, double *Csphere, double *delta, bool treatActiveFlag, double *bary);
+
+        #endif
+
         bool resolveTriSphereNeighbuild(int nTri, double rSphere, double *cSphere, double treshold);
 
         #ifdef TRI_LINE_ACTIVE_FLAG
@@ -102,11 +125,14 @@ namespace LAMMPS_NS
                                     double *p, double *delta, double *bary);
         double resolveEdgeContactBary(int iTri, int iEdge, double *p, double *delta, double *bary);
         double resolveFaceContactBary(int iTri, double *p, double *node0ToSphereCenter, double *delta);
-
   };
 
   // *************************************
   #include "tri_mesh_I.h"
+  #ifdef SUPERQUADRIC_ACTIVE_FLAG
+  #include "tri_mesh_I_superquadric.h"
+  #endif
+
   #ifdef TRI_LINE_ACTIVE_FLAG
   #include "tri_mesh_I_line.h"
   #endif
